/*-------------------------------*-C++-*--------------------------------*
 * File:	scrollbar.cpp
 *----------------------------------------------------------------------*
 * All portions of code are copyright by their respective author/s.
 * Copyright (c) 1997,1998 mj olesen <olesen@me.QueensU.CA>
 * Copyright (c) 1998      Alfredo K. Kojima <kojima@windowmaker.org>
 *				- N*XTstep like scrollbars
 * Copyright (c) 1999-2001 Geoff Wing <gcw@pobox.com>
 * Copyright (c) 2002      Gilles Filippini <pini@free.fr>
 *        - FXvt
 *
 * This file is part of FXvt.
 *
 * FXvt is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * FXvt is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FXvt; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------*/

#include "../config.h"		/* NECESSARY */
#include "rxvt.h"		/* NECESSARY */
#include "scrollbar.intpro"	/* PROTOS for internal routines */

#include <fox/fx.h>
#include "FXvt.h"

/*----------------------------------------------------------------------*/

/*
 * Map or unmap a scrollbar.  Returns non-zero upon change of state
 */
/* EXTPROTO */
int
rxvt_scrollbar_mapping(rxvt_t *r, int map)
{
    int             change = 0;
#ifdef HAVE_SCROLLBARS

    if (map && !scrollbar_visible(r)) {
	scrollbar_setIdle();
	if (!r->scrollBar.win)
	    rxvt_Resize_scrollBar(r);
	if (r->scrollBar.win) {
	    XMapWindow(r->Xdisplay, r->scrollBar.win);
	    change = 1;
	}
    } else if (!map && scrollbar_visible(r)) {
	r->scrollBar.state = 0;
	XUnmapWindow(r->Xdisplay, r->scrollBar.win);
	change = 1;
    }
#endif
    return change;
}

/* EXTPROTO */
void
rxvt_Resize_scrollBar(rxvt_t *r)
{
	rxvt_scrollbar_show(r, 1);
}

/*
 * Update current scrollbar view w.r.t. slider heights, etc.
 */
/* EXTPROTO */
int
rxvt_scrollbar_show(rxvt_t *r, int update)
{
	int             ret = 0;
#ifdef HAVE_SCROLLBARS
	int             top, bot, len, adj;
	
	if (!scrollbar_visible(r))
		return 0;
	
	if (update) {
		top = (r->TermWin.nscrolled - r->TermWin.view_start);
		bot = top + (r->TermWin.nrow - 1);
		len = max((r->TermWin.nscrolled + (r->TermWin.nrow - 1)), 1);
		adj = (((bot - top) * scrollbar_size()) % len) > 0 ? 1 : 0;
		
		r->scrollBar.top = (r->scrollBar.beg + (top * scrollbar_size()) / len);
		r->h->scrollbar_len = ((bot - top) * scrollbar_size()) / len +
			scrollbar_minheight() + adj;
		r->scrollBar.bot = (r->scrollBar.top + r->h->scrollbar_len);
		/* no change */
		if (r->scrollBar.top == r->h->last_top
				&& r->scrollBar.bot == r->h->last_bot
				&& (r->scrollBar.state == r->h->last_state || !scrollbar_isUpDn()))
	    return 0;
	}
	
	/*r->fxvt->updateScrollBar(update, r->h->last_top, r->h->last_bot,
		r->h->scrollbar_len);*/

	/*ret = r->scrollBar.update(r, update, r->h->last_top, r->h->last_bot,
		r->h->scrollbar_len);*/
	
	r->h->last_top = r->scrollBar.top;
	r->h->last_bot = r->scrollBar.bot;
	r->h->last_state = r->scrollBar.state;
	
#endif
	return ret;
}

/* EXTPROTO */
void
rxvt_setup_scrollbar(rxvt_t *r, const char *scrollalign, const char *scrollstyle, const char *thickness)
{
#ifdef HAVE_SCROLLBARS
	r->scrollBar.style = R_SB_FOX;
	r->scrollBar.width = 15;
	
	/* r->h->scrollbar_align = R_SB_ALIGN_CENTRE; */
	if (scrollalign) {
		if (STRNCASECMP(scrollalign, "top", 3) == 0)
	    r->h->scrollbar_align = R_SB_ALIGN_TOP;
		else if (STRNCASECMP(scrollalign, "bottom", 6) == 0)
	    r->h->scrollbar_align = R_SB_ALIGN_BOTTOM;
	}
#endif
}

/*----------------------- end-of-file (C source) -----------------------*/
