/*-------------------------------*-C++-*--------------------------------*
 * File:	fxvt.cpp
 *----------------------------------------------------------------------*
 * Copyright (c) 2002      Gilles Filippini <pini@free.fr>
 *        - FXvt
 *
 * This file is part of FXvt.
 *
 * FXvt is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * FXvt is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FXvt; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------*/

#include <fox/fx.h>
#include <FXvt.h>

using namespace fxvt;

// FXvt needs a customized FXApp which inherits from FXvtApplication.
// It must redefine FXApp::dispatchEvent() and FXvtApplication::getCurEvent
// as follows.
class Application : public FXApp, public FXvtApplication
{
protected:
	FXRawEvent * curEvent;
	FXRawEvent * getCurEvent() { return curEvent; }
protected:
	virtual FXbool dispatchEvent(FXRawEvent& ev);
public:
	Application();
};

Application::Application() :
	FXApp("fxvt", "pini"), curEvent(NULL)
{
}

FXbool Application::dispatchEvent(FXRawEvent& ev)
{
	curEvent = &ev;
	return FXApp::dispatchEvent(ev);
}

int main(int argc, char * argv[])
{
	Application application;
	application.init(argc, argv);
	application.create();

	FXMainWindow * mainWin = new FXMainWindow(&application, "fxvt", NULL, NULL, DECOR_ALL);
	FXvt * fxvt = new FXvt(mainWin, 50, 80, NULL, 0, LAYOUT_FILL_X|LAYOUT_FILL_Y);

	mainWin->create();

	// Use one of the exec functions to launch an app into the terminal
	// Here we launch the default shell
	fxvt->execShell();

	// We could have launched irb as well...
	// fxvt->execlp("irb", "irb", NULL);

	// Or the Debian tool aptitude
	// fxvt->execlp("aptitude", "aptitude", NULL);

	mainWin->show(PLACEMENT_SCREEN);
	application.run();

	return EXIT_SUCCESS;
}
